@@ -12,21 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from __future__ import annotations
-from .emoji import EmojiReactionSummary
-from .user import User
-from .space import Space
-from .card import Card, CardWithId
-from .attachment import Attachment
-from .annotation import Annotation
-from .action_response import ActionResponse
-from .widgets.button_list import ButtonList
 
 import dataclasses
-from typing import Any, List, Mapping, Optional
+from typing import List
 
 import dataclasses_json
-from card_framework import AutoNumber, Renderable, list_field
-from card_framework import standard_field, enum_field
+
+from card_framework import (AutoNumber, Renderable, enum_field, list_field,
+                            standard_field)
+
+from .action_response import ActionResponse
+from .annotation import Annotation
+from .attachment import Attachment
+from .card import Card, CardWithId
+from .emoji import EmojiReactionSummary
+from .space import Space
+from .user import User
+from .widgets.button_list import ButtonList
 
 
 @dataclasses_json.dataclass_json
@@ -41,7 +43,8 @@ class Message(Renderable):
   delete_time: str = standard_field()
   text: str = standard_field()
   cards: List[Card] = list_field()
-  cards_v2: List[CardWithId] = list_field(letter_case=dataclasses_json.LetterCase.SNAKE)
+  cards_v2: List[CardWithId] = list_field(
+      letter_case=dataclasses_json.LetterCase.CAMEL)
   annotations: List[Annotation] = list_field()
   thread: Thread = standard_field()
   space: Space = standard_field()
@@ -55,12 +58,27 @@ class Message(Renderable):
   client_assigned_message_id: str = standard_field()
   emoji_reaction_summaries: List[EmojiReactionSummary] = list_field()
   private_message_viewer: User = standard_field()
-  deletion_metadata: DeletionMetaData = standard_field()
+  deletion_metadata: DeletionMetadata = standard_field()
   quoted_message_metadata: QuotedMessageMetadata = standard_field()
   attached_gifs: List[AttachedGif] = list_field()
   accessory_widgets: List[AccessoryWidget] = list_field()
 
 
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
+class DeletionMetadata(object):
+  class DeletionType(AutoNumber):
+    DELETION_TYPE_UNSPECIFIED = ()
+    CREATOR = ()
+    SPACE_OWNER = ()
+    ADMIN = ()
+    APP_MESSAGE_EXPIRY = ()
+    CREATOR_VIA_APP = ()
+    SPACE_OWNER_VIA_APP = ()
+
+  deletion_type: DeletionType = enum_field()
+
+
 @dataclasses_json.dataclass_json
 @dataclasses.dataclass
 class Thread(object):
@@ -79,21 +97,6 @@ class MatchedUrl(object):
   url: str = standard_field()
 
 
-@dataclasses_json.dataclass_json
-@dataclasses.dataclass
-class DeletionMetadata(object):
-  class DeletionType(AutoNumber):
-    DELETION_TYPE_UNSPECIFIED = ()
-    CREATOR = ()
-    SPACE_OWNER = ()
-    ADMIN = ()
-    APP_MESSAGE_EXPIRY = ()
-    CREATOR_VIA_APP = ()
-    SPACE_OWNER_VIA_APP = ()
-
-  deletion_type: DeletionType = enum_field()
-
-
 @dataclasses_json.dataclass_json
 @dataclasses.dataclass
 class QuotedMessageMetadata(object):
